Range-v3: Member List

Range-v3 Range algorithms, views, and actions for the Standard Library |

ranges::v3::concepts::BidirectionalIterator Member List

This is the complete list of members for ranges::v3::concepts::BidirectionalIterator, including all inherited members.

base_concepts_t typedef (defined in ranges::v3::concepts::refines< ForwardIterator >) | ranges::v3::concepts::refines< ForwardIterator > |
refines()=delete (defined in ranges::v3::concepts::refines< ForwardIterator >) | ranges::v3::concepts::refines< ForwardIterator > |
requires_(I i) -> decltype(concepts::valid_expr(concepts::model_of< DerivedFrom, category_t< I >, ranges::bidirectional_iterator_tag >(), concepts::has_type< I &>(--i), concepts::has_type< I >(i--), concepts::same_type(*i, *i--))) (defined in ranges::v3::concepts::BidirectionalIterator) | ranges::v3::concepts::BidirectionalIterator |
requires_() (defined in ranges::v3::concepts::refines< ForwardIterator >) | ranges::v3::concepts::refines< ForwardIterator > |